@@ -5,8 +5,7 @@ class OutputLoader():
     def save(obj, path):
         os.makedirs(os.path.dirname(path), exist_ok=True)
         with open(path, 'wb') as handle:
-            #pickle.dump(obj, handle, protocol=pickle.HIGHEST_PROTOCOL)
-            pickle.dump(obj, handle)
+            pickle.dump(obj, handle, protocol=pickle.HIGHEST_PROTOCOL)
 
     def load(path):
         with open(path, 'rb') as handle:
